@@ -1035,25 +1035,10 @@ impl DrawingCtx {
         pattern: &UserSpacePattern,
         acquired_nodes: &mut AcquiredNodes<'_>,
     ) -> Result<bool, RenderingError> {
-        // Bail out early if the pattern has zero size, per the spec
         if approx_eq!(f64, pattern.width, 0.0) || approx_eq!(f64, pattern.height, 0.0) {
             return Ok(false);
         }
 
-        // Bail out early if this pattern has a circular reference
-        let pattern_node_acquired = match pattern.acquire_pattern_node(acquired_nodes) {
-            Ok(n) => n,
-
-            Err(AcquireError::CircularReference(ref node)) => {
-                rsvg_log!("circular reference in element {}", node);
-                return Ok(false);
-            }
-
-            _ => unreachable!(),
-        };
-
-        let pattern_node = pattern_node_acquired.get();
-
         let taffine = self.get_transform().pre_transform(&pattern.transform);
 
         let mut scwscale = (taffine.xx.powi(2) + taffine.xy.powi(2)).sqrt();
@@ -1099,10 +1084,11 @@ impl DrawingCtx {
 
             pattern_draw_ctx
                 .with_alpha(pattern.opacity, &mut |dc| {
-                    let pattern_cascaded = CascadedValues::new_from_node(pattern_node);
+                    let pattern_cascaded =
+                        CascadedValues::new_from_node(&pattern.node_with_children);
                     let pattern_values = pattern_cascaded.get();
 
-                    let elt = pattern_node.borrow_element();
+                    let elt = pattern.node_with_children.borrow_element();
 
                     let stacking_ctx = StackingContext::new(
                         acquired_nodes,
@@ -1118,7 +1104,12 @@ impl DrawingCtx {
                         false,
                         None,
                         &mut |an, dc, _transform| {
-                            pattern_node.draw_children(an, &pattern_cascaded, dc, false)
+                            pattern.node_with_children.draw_children(
+                                an,
+                                &pattern_cascaded,
+                                dc,
+                                false,
+                            )
                         },
                     )
                 })
@@ -1397,11 +1388,6 @@ impl DrawingCtx {
             return Ok(self.empty_bbox());
         }
 
-        // #851 - We can't just render all text as paths for PDF; it
-        // needs the actual text content so text is selectable by PDF
-        // viewers.
-        let can_use_text_as_path = self.cr.target().type_() != cairo::SurfaceType::Pdf;
-
         with_saved_cr(&self.cr.clone(), || {
             self.cr
                 .set_antialias(cairo::Antialias::from(span.text_rendering));
@@ -1430,25 +1416,9 @@ impl DrawingCtx {
                                 self.set_paint_source(&span.fill_paint, acquired_nodes)?;
 
                             if had_paint_server {
-                                if can_use_text_as_path {
-                                    path.to_cairo(&self.cr, false)?;
-                                    self.cr.fill()?;
-                                    self.cr.new_path();
-                                } else {
-                                    self.cr.move_to(span.x, span.y);
-
-                                    let matrix = self.cr.matrix();
-
-                                    let rotation_from_gravity = span.gravity.to_rotation();
-                                    if !rotation_from_gravity.approx_eq_cairo(0.0) {
-                                        self.cr.rotate(-rotation_from_gravity);
-                                    }
-
-                                    pangocairo::functions::update_layout(&self.cr, &span.layout);
-                                    pangocairo::functions::show_layout(&self.cr, &span.layout);
-
-                                    self.cr.set_matrix(matrix);
-                                }
+                                path.to_cairo(&self.cr, false)?;
+                                self.cr.fill()?;
+                                self.cr.new_path();
                             }
                         }
 
