@@ -195,10 +195,10 @@ fn parse_dropshadow<'i>(parser: &mut Parser<'i, '_>) -> Result<FilterFunction, P
     result.color = parser.try_parse(Color::parse).ok();
 
     // if dx is provided, dy must follow and an optional std_dev must follow that.
-    if let Ok(dx) = parser.try_parse(|p| Length::parse(p)) {
+    if let Ok(dx) = parser.try_parse(Length::parse) {
         result.dx = Some(dx);
-        result.dy = Some(parser.try_parse(|p| Length::parse(p))?);
-        result.std_deviation = parser.try_parse(|p| ULength::parse(p)).ok();
+        result.dy = Some(parser.try_parse(Length::parse)?);
+        result.std_deviation = parser.try_parse(ULength::parse).ok();
     }
 
     let loc = parser.current_source_location();
