@@ -1,4 +1,3 @@
-use float_cmp::approx_eq;
 use gio::MemoryInputStream;
 use glib::Bytes;
 use predicates::prelude::*;
@@ -105,6 +104,10 @@ impl cmp::PartialEq for Dimensions {
 
 impl cmp::Eq for Dimensions {}
 
+trait Details {
+    fn get_size(&self) -> Option<Dimensions>;
+}
+
 impl DetailPredicate<SvgPredicate> {
     fn eval_doc(&self, handle: &SvgHandle) -> bool {
         match &self.d {
